# 🔉 vl8: Create derivative works that might not be copyright violations 🔉

![vl8 logo](https://raw.githubusercontent.com/rec/vl8/master/vl8.png)

Update: this is still in development - I got sidetracked by paying work.
Most of this is working, it just needs to be packaged!

------------------------------------------------------------------------

A command line tool and Python library that (will soon be) like a Swiss
Army Knife for audio.

-   Create a myriad of mashups of your favorite audio effortlessly.
-   Script mundane tasks like editing, scaling and stretching,
    envelopes, playlists and more.
-   Handle very large audio files using memory mapping, or very large
    numbers of audio files using scripting.
-   Write your own scripts for mashups or editing, or your own plug-ins,
    and share them.
-   Uses widely compatible, highly performant numpy arrays to represent
    audio files within Python.
